
function [f,theResult] = rd_housekeep(theNetCDFFile)

%
% read in all variables in a AERI or NAST NetCDF files 
% except for the radiances.  returns structure "theResult"
% of all data except the radiances, and the netcdf object f 
% for later access to the netcdf file.
%
% DCT 7-16-98

% get filename if not input
if nargin == 0
  [filename,pathname] = uigetfile;
  theNetCDFFile = [pathname filename];
end

% open netcdf files and get file info
f = netcdf(theNetCDFFile, 'nowrite');
if isempty(f);return;end

% get and store variable names
variables = ncnames(var(f));
theResult.variables = variables;

% loop over variable names, reading them in and assigning them to 
% the data structure if they are not the radiances.

for i = 1:length(variables)
  % if there is a '-' in the variable name, don't read it in
  if isempty(find(variables{i} == '-')) 
    if ~strcmp(variables{i},'Radiance') & ...
       ~strcmp(variables{i},'mean_rad') & ...
       ~strcmp(variables{i},'atmosphericRadiance') 
	   eval(['theResult.' variables{i} ' = f{variables{i}}(:);'])
    else
           % keep track of radiance variable name
	   theResult.Rname = variables{i};
    end
  end
end




